@@ -65,7 +65,7 @@ class IpacHeaderSplitter(core.BaseSplitter):
 
 
 class IpacHeader(fixedwidth.FixedWidthHeader):
-    """IPAC table header"""
+    """IPAC table header."""
 
     splitter_class = IpacHeaderSplitter
 
@@ -86,7 +86,8 @@ class IpacHeader(fixedwidth.FixedWidthHeader):
 
     def process_lines(self, lines):
         """Generator to yield IPAC header lines, i.e. those starting and ending with
-        delimiter character (with trailing whitespace stripped)"""
+        delimiter character (with trailing whitespace stripped).
+        """
         delim = self.splitter.delimiter
         for line in lines:
             line = line.rstrip()
@@ -96,7 +97,7 @@ class IpacHeader(fixedwidth.FixedWidthHeader):
     def update_meta(self, lines, meta):
         """
         Extract table-level comments and keywords for IPAC table.  See:
-        https://irsa.ipac.caltech.edu/applications/DDGEN/Doc/ipac_tbl.html#kw
+        https://irsa.ipac.caltech.edu/applications/DDGEN/Doc/ipac_tbl.html#kw.
         """
 
         def process_keyword_value(val):
@@ -315,8 +316,8 @@ class IpacHeader(fixedwidth.FixedWidthHeader):
         The width of each column is determined in Ipac.write. Writing the header
         must be delayed until that time.
         This function is called from there, once the width information is
-        available."""
-
+        available.
+        """
         for vals in self.str_vals():
             lines.append(self.splitter.join(vals, widths))
         return lines
@@ -329,7 +330,7 @@ class IpacDataSplitter(fixedwidth.FixedWidthSplitter):
 
 
 class IpacData(fixedwidth.FixedWidthData):
-    """IPAC table data reader"""
+    """IPAC table data reader."""
 
     comment = r"[|\\]"
     start_line = 0
@@ -337,7 +338,7 @@ class IpacData(fixedwidth.FixedWidthData):
     fill_values = [(core.masked, "null")]
 
     def write(self, lines, widths, vals_list):
-        """IPAC writer, modified from FixedWidth writer"""
+        """IPAC writer, modified from FixedWidth writer."""
         for vals in vals_list:
             lines.append(self.splitter.join(vals, widths))
         return lines
@@ -449,6 +450,7 @@ class Ipac(basic.Basic):
         `IPAC <https://irsa.ipac.caltech.edu/applications/DDGEN/Doc/ipac_tbl.html>`_
         definition.
     """
+
     _format_name = "ipac"
     _io_registry_format_aliases = ["ipac"]
     _io_registry_can_write = True
