@@ -13,7 +13,6 @@ import math
 
 import numpy as np
 
-import astropy.units as u
 
 from . import _stats
 
@@ -218,7 +217,7 @@ def binom_conf_interval(k, n, confidence_level=0.68269, interval="wilson"):
     array([[-0.26077835, -0.16433593],
            [ 0.66077835,  0.96433593]])
 
-    """  # noqa: E501
+    """
     if confidence_level < 0.0 or confidence_level > 1.0:
         raise ValueError("confidence_level must be between 0. and 1.")
     alpha = 1.0 - confidence_level
@@ -480,7 +479,7 @@ def _check_poisson_conf_inputs(sigma, background, confidence_level, name):
 def poisson_conf_interval(
     n, interval="root-n", sigma=1, background=0, confidence_level=None
 ):
-    r"""Poisson parameter confidence interval given observed counts
+    r"""Poisson parameter confidence interval given observed counts.
 
     Parameters
     ----------
@@ -508,7 +507,6 @@ def poisson_conf_interval(
 
     Notes
     -----
-
     The "right" confidence interval to use for Poisson data is a
     matter of debate. The CDF working group `recommends
     <https://web.archive.org/web/20210222093249/https://www-cdf.fnal.gov/physics/statistics/notes/pois_eb.txt>`_
@@ -551,7 +549,7 @@ def poisson_conf_interval(
 
     **4. 'sherpagehrels'** This rule is used by default in the fitting
     package 'sherpa'. The `documentation
-    <https://cxc.harvard.edu/sherpa4.4/statistics/#chigehrels>`_ claims
+    <https://cxc.cfa.harvard.edu/sherpa/statistics/#chigehrels>`_ claims
     it is based on a numerical approximation published in `Gehrels
     (1986) <https://ui.adsabs.harvard.edu/abs/1986ApJ...303..336G>`_ but it
     does not actually appear there.  It is symmetrical, and while the
@@ -613,7 +611,7 @@ def poisson_conf_interval(
     insensitive to the choice of prior.
 
     This function has an optional dependency: Either `Scipy
-    <https://www.scipy.org/>`_ or `mpmath <http://mpmath.org/>`_  need
+    <https://www.scipy.org/>`_ or `mpmath <https://mpmath.org/>`_  need
     to be available (Scipy works only for N < 100).
     This code is very intense numerically, which makes it much slower than
     the other methods, in particular for large count numbers (above 1000
@@ -680,8 +678,7 @@ def poisson_conf_interval(
     ...     interval='kraft-burrows-nousek').T  # doctest: +FLOAT_CMP
     array([[ 3.47894005, 16.113329533]])
 
-    """  # noqa: E501
-
+    """
     if not np.isscalar(n):
         n = np.asanyarray(n)
 
@@ -794,7 +791,6 @@ def median_absolute_deviation(data, axis=None, func=None, ignore_nan=False):
     --------
     mad_std
     """
-
     if func is None:
         # Check if the array has a mask and if so use np.ma.median
         # See https://github.com/numpy/numpy/issues/7330 why using np.ma.median
@@ -818,30 +814,12 @@ def median_absolute_deviation(data, axis=None, func=None, ignore_nan=False):
     # np.nanmedian has `keepdims`, which is a good option if we're not allowing
     # user-passed functions here
     data_median = func(data, axis=axis)
-    # this conditional can be removed after this PR is merged:
-    # https://github.com/astropy/astropy/issues/12165
-    if (
-        isinstance(data, u.Quantity)
-        and func is np.median
-        and data_median.ndim == 0
-        and np.isnan(data_median)
-    ):
-        data_median = data.__array_wrap__(data_median)
 
     # broadcast the median array before subtraction
     if axis is not None:
         data_median = np.expand_dims(data_median, axis=axis)
 
     result = func(np.abs(data - data_median), axis=axis, overwrite_input=True)
-    # this conditional can be removed after this PR is merged:
-    # https://github.com/astropy/astropy/issues/12165
-    if (
-        isinstance(data, u.Quantity)
-        and func is np.median
-        and result.ndim == 0
-        and np.isnan(result)
-    ):
-        result = data.__array_wrap__(result)
 
     if axis is None and np.ma.isMaskedArray(result):
         # return scalar version
@@ -907,7 +885,6 @@ def mad_std(data, axis=None, func=None, ignore_nan=False):
     --------
     biweight_midvariance, biweight_midcovariance, median_absolute_deviation
     """
-
     # NOTE: 1. / scipy.stats.norm.ppf(0.75) = 1.482602218505602
     MAD = median_absolute_deviation(data, axis=axis, func=func, ignore_nan=ignore_nan)
     return MAD * 1.482602218505602
@@ -1070,7 +1047,7 @@ def bootstrap(data, bootnum=100, samples=None, bootfunc=None):
 
 
 def _scipy_kraft_burrows_nousek(N, B, CL):
-    """Upper limit on a poisson count rate
+    """Upper limit on a poisson count rate.
 
     The implementation is based on Kraft, Burrows and Nousek
     `ApJ 374, 344 (1991) <https://ui.adsabs.harvard.edu/abs/1991ApJ...374..344K>`_.
@@ -1096,9 +1073,8 @@ def _scipy_kraft_burrows_nousek(N, B, CL):
     about N > 100 (the exact limit depends on details of how scipy was
     compiled). See `~astropy.stats.mpmath_poisson_upper_limit` for an
     implementation that is slower, but can deal with arbitrarily high numbers
-    since it is based on the `mpmath <http://mpmath.org/>`_ library.
+    since it is based on the `mpmath <https://mpmath.org/>`_ library.
     """
-
     from math import exp
 
     from scipy.integrate import quad
@@ -1149,7 +1125,7 @@ def _scipy_kraft_burrows_nousek(N, B, CL):
 
 
 def _mpmath_kraft_burrows_nousek(N, B, CL):
-    """Upper limit on a poisson count rate
+    """Upper limit on a poisson count rate.
 
     The implementation is based on Kraft, Burrows and Nousek in
     `ApJ 374, 344 (1991) <https://ui.adsabs.harvard.edu/abs/1991ApJ...374..344K>`_.
@@ -1171,7 +1147,7 @@ def _mpmath_kraft_burrows_nousek(N, B, CL):
 
     Notes
     -----
-    Requires the `mpmath <http://mpmath.org/>`_ library.  See
+    Requires the `mpmath <https://mpmath.org/>`_ library.  See
     `~astropy.stats.scipy_poisson_upper_limit` for an implementation
     that is based on scipy and evaluates faster, but runs only to about
     N = 100.
@@ -1244,7 +1220,7 @@ def _mpmath_kraft_burrows_nousek(N, B, CL):
 
 
 def _kraft_burrows_nousek(N, B, CL):
-    """Upper limit on a poisson count rate
+    """Upper limit on a poisson count rate.
 
     The implementation is based on Kraft, Burrows and Nousek in
     `ApJ 374, 344 (1991) <https://ui.adsabs.harvard.edu/abs/1991ApJ...374..344K>`_.
@@ -1267,7 +1243,7 @@ def _kraft_burrows_nousek(N, B, CL):
     Notes
     -----
     This functions has an optional dependency: Either :mod:`scipy` or `mpmath
-    <http://mpmath.org/>`_  need to be available. (Scipy only works for
+    <https://mpmath.org/>`_  need to be available. (Scipy only works for
     N < 100).
     """
     from astropy.utils.compat.optional_deps import HAS_MPMATH, HAS_SCIPY
@@ -1312,7 +1288,6 @@ def kuiper_false_positive_probability(D, N):
 
     References
     ----------
-
     .. [1] Paltani, S., "Searching for periods in X-ray observations using
            Kuiper's test. Application to the ROSAT PSPC archive",
            Astronomy and Astrophysics, v.240, p.789-790, 2004.
@@ -1430,7 +1405,6 @@ def kuiper(data, cdf=lambda x: x, args=()):
 
     References
     ----------
-
     .. [1] Stephens, M. A., "Use of the Kolmogorov-Smirnov, Cramer-Von Mises
            and Related Statistics Without Extensive Tables", Journal of the
            Royal Statistical Society. Series B (Methodological), Vol. 32,
@@ -1438,7 +1412,6 @@ def kuiper(data, cdf=lambda x: x, args=()):
 
 
     """
-
     data = np.sort(data)
     cdfv = cdf(data, *args)
     N = len(data)
@@ -1475,7 +1448,7 @@ def kuiper_two(data1, data2):
     data2 = np.sort(data2)
     (n1,) = data1.shape
     (n2,) = data2.shape
-    common_type = np.find_common_type([], [data1.dtype, data2.dtype])
+    common_type = np.result_type(data1.dtype, data2.dtype)
     if not (
         np.issubdtype(common_type, np.number)
         and not np.issubdtype(common_type, np.complexfloating)
